# MTR's config file for tkabber

set ssj::options(sign-traffic)    1
set ssj::options(encrypt-traffic) 1

set debug_lvls                    [list message presence ssj warning]
set debug_winP                    0

set raise_new_tab                 0

set show_splash_window            1

set use_ispell                    1

proc debugmsg {module msg} {
    global debug_lvls w
    global debug_fd debug_winP

    if {![info exists debug_fd]} {
        catch { file rename -force -- ~/.tkabber/tkabber.log \
                                      ~/.tkabber/tkabber0.log }
        set debug_fd [open ~/.tkabber/tkabber.log \
                           { WRONLY CREAT TRUNC APPEND }]
        fconfigure $debug_fd -buffering line
    }

    puts $debug_fd [format "%s %-12.12s %s" \
                           [clock format [clock seconds] -format "%m/%d %T"] \
                           $module $msg]

    if {([lsearch -exact $debug_lvls $module] < 0) || (!$debug_winP)} {
        return
    }

    set dw $w.debug

    if {![winfo exists $dw]} {
        add_win $dw -title Debug -tabtitle debug 

        [ScrolledWindow $dw.sw] setwidget \
            [text $dw.body -yscrollcommand [list $dw.scroll set]]

        pack $dw.sw -side bottom -fill both -expand yes

        $dw.body tag configure module -foreground red3
        $dw.body tag configure proc  -foreground blue
        $dw.body tag configure error -foreground red
    }

    $dw.body insert end [format "%-12.12s" $module] module " "
    set tag normal
    switch -- $module {
        jlib {
            if {[set x [string first "(jlib::" $msg]] > 0} {
                set tag error
            }
            if {[set y [string first ")" $msg]] > 0} {
                $dw.body insert end \
                         [string range $msg [expr $x+7] [expr $y-1]] proc \
                         "\n"
                set msg [string trimleft \
                                [string range $msg [expr $y+1] end]]
            }
        }

        default {
        }
    }
    $dw.body insert end [string trimright $msg] $tag
    $dw.body insert end "\n\n"
}

set load_default_xrdb 0
# option readfile /home/mrose/src/tkabber/examples/black.xrdb userDefault
tk_bisque


proc postload {} {
# the emoticon module

    emoteicons::load_dir ~/.tkabber/emoticons/rythmbox


# the ispell module

    set plugins::ispell::options(executable) ispell


# the login module

    global loginconf loginconf1 loginconf2

    set loginconf1(profile)     "Default"
    set loginconf1(user)        mrose

    set loginconf2(profile)     "Test Account"
    set loginconf2(user)        test

    set loginconf(password)      ""
    set loginconf(resource)      tkabber
    set loginconf(server)        jabber.dbc.mtview.ca.us
    set loginconf(port)          5222
    set loginconf(priority)      8
    set loginconf(usessl)        1
    set loginconf(sslport)       5223
    set loginconf(useproxy)      0
    set loginconf(httpproxy)     localhost
    set loginconf(httpproxyport) 3128

    array set loginconf          [array get loginconf1]


# the message module

    set message::options(headlines,cache) 1


# the roster module

    set roster::show_only_online 1
    set roster::roster(collapsed,RSS) 1
    set roster::roster(collapsed,Undefined) 1
}


proc menuload {menudesc} {
    global version

return                                                                        \
[list                                                                         \
&TKabber "" "" 1                                                              \
      [list                                                                   \
            [list cascad  Presence                            "" presence 1   \
                  [list                                                       \
                        [list command Online               "" "" ""           \
                              -command "set userstatus available"]            \
                        [list command "Free to chat"          "" "" ""        \
                                      -command "set userstatus chat"]         \
                        [list command Away                    "" "" ""        \
                                      -command "set userstatus away"]         \
                        [list command "Extended Away"         "" "" ""        \
                                      -command "set userstatus xa"]           \
                        [list command Busy                    "" "" ""        \
                                      -command "set userstatus dnd"]          \
                        [list command Invisible               "" "" ""        \
                                      -command "set userstatus invisible"]    \
                  ]                                                           \
            ]                                                                 \
            [list command "&Log in..."                        "" "" "Ctrl L"  \
                              -command show_login_dialog]                     \
            [list command "Log &out"                          "" "" ""        \
                              -command logout]                                \
            [list command "Log out &with Reason..."           "" "" ""        \
                              -command show_logout_dialog]                    \
            separator                                                         \
            [list cascad  &Roster                             "" roster 1     \
                  [list                                                       \
                        [list checkbutton                                     \
                                     "Hide &Offline contacts" "" "" "Ctrl H"  \
                              -command roster::redraw                         \
                              -variable roster::show_only_online]             \
                  ]                                                           \
            ]                                                                 \
            separator                                                         \
            [list command "&My Information..."                "" "" ""        \
                              -command {                                      
userinfo::open ${loginconf(user)}@$loginconf(server)/$loginconf(resource) 1
}]                                                                            \
            [list cascad  &Preferences                        "" preferences 1\
                [list                                                         \
                      [list checkbutton "Announce avatar"                     \
                                                              "" "" ""        \
                            -variable avatar::options(announce)]              \
                      [list checkbutton "Allow avatar to be downloaded"       \
                                                              "" "" ""        \
                            -variable avatar::options(share)]                 \
                      [list command "Store avatar on server"  "" "" ""        \
                            -command avatar::store_on_server]                 \
                      [list cascad  JIDlink                   "" jidlink 1 ""]\
                      separator                                               \
                      [list checkbutton "Auto-scroll"         "" "" ""        \
                            -onvalue  0                                       \
                            -offvalue 1                                       \
                            -variable chat::options(stop_scroll)]             \
                      [list checkbutton "Default to chat"     "" "" ""        \
                            -onvalue  chat                                    \
                            -offvalue message                                 \
                            -variable chat::options(default_message_type)]    \
                      separator                                               \
                      [list checkbutton "Encrypt traffic (when possible)"     \
                                                              "" "" ""        \
                            -variable ssj::options(encrypt-traffic)]          \
                      [list checkbutton "Sign traffic"        "" "" ""        \
                            -variable ssj::options(sign-traffic)]             \
                ]                                                             \
            ]                                                                 \
            separator                                                         \
            [list command E&xit                               "" "" "Ctrl Q"  \
                              -command quit]                                  \
      ]                                                                       \
                                                                              \
&Services "" "" 1                                                             \
      [list                                                                   \
            [list command "New Blank &Message"                "" "" ""        \
                              -command message::send_dialog]                  \
            separator                                                         \
            [list command "&Add Contact..."                   "" "" "Ctrl U"  \
                              -command message::send_subscribe_dialog]        \
            [list command "Add &Group..."                     "" "" ""        \
                              -command add_group_dialog]                      \
            [list command "Browse Agents/IM Systems..."       "" "" "Ctrl B"  \
                              -command browser::open]                         \
            separator                                                         \
            [list command "Join Group &Chat"                  "" "" "Ctrl C"  \
                              -command join_group_dialog]                     \
            [list command "Jabber Message &Rules"             "" "" ""        \
                              -command filters::open]                         \
      ]                                                                       \
                                                                              \
&Help "" "" 1                                                                 \
      [list                                                                   \
            [list command "&Quick Help"                   "" "" ""            \
                              -command {
help_window "Quick Help" "
Tabs:
    C-F4		Close tab
    C-PgUp/Down	Previous/Next tab
    C-r		Hide/Show roster 

Chats:
    TAB		Complete nickname
    C-Up/Down	Previous/Next history message
    Alt-e		Show emoticons
    C-z		Undo
    C-Z		Redo
    Alt-PgUp/Down	Scroll chat window up/down
    Right mouse	Correct word
"}]                                                                           \
            [list command "&About..."                     "" "" ""            \
                              -command about_window]                          \
            [list cascad   &Debug                            "" debug 1       \
                [debug_buttons]                                               \
            ]                                                                 \
            [list command "&Raw XML Input..."             "" "" ""            \
                          -command show_rawxml_dialog]                        \
      ]                                                                       \
]
}

proc debug_buttons {} {
    global debug_modules debug_lvls

    set buttons {}
    foreach l [list avatar       browser      chat         completion   \
                    conference   filetransfer filters      hook         \
                    iq           jlib         logger       login        \
                    message      nick         plugins      presence     \
                    register     roster       search       ssj          \
                    tkabber      userinfo     warning] {
        if {[lsearch -exact $debug_lvls $l] >= 0} {
            set debug_modules($l) 1
        } else {
            set debug_modules($l) 0
        }

        lappend buttons \
                [list checkbutton $l {} {} {} \
                      -variable debug_modules($l) -command debug_update]
    }

    return $buttons
}

proc debug_update {} {
    global debug_modules debug_lvls
    
    set debug_lvls {}
    foreach {k v} [array get debug_modules] {
        if {$v} {
            lappend debug_lvls $k
        }
    }
}
