# $Id: sound.tcl,v 1.3 2002/10/29 20:20:00 alexey Exp $

namespace eval sound {
    variable options
    variable groupchat_may_notify
    # Sound is off by default
    set options(sound) 0
    set options(mute) 0
    # One could use external play program instead of Snack
    set options(external_play_program) ""
    # Sound theme
    set options(theme) "default"
    variable play_id ""
    variable play_priority 0
    # Do not allow play sound very often
    set options(delay) 200
}

proc sound::sound_setup {} {
    variable options
    variable groupchat_may_notify
    variable sounds

    if {!$options(sound)} return

    set names [list groupchat_server_message groupchat_my_message \
		    groupchat_their_message chat_my_message \
		    chat_their_message connected \
		    presence_available presence_unavailable \
		    groupchat_their_message_to_me]

    foreach name $names {
	if {[regexp {^[/~]} $options(theme)]} {
	    set fname [file join $options(theme) $name.wav]
	} else {
	    set fname [fullpath sounds $options(theme) $name.wav]
	}
	if {[file exist $fname]} {
	    set sounds($name) $fname
	} else {
	    set sounds($name) ""
	}
    }

    if {$options(external_play_program) == ""} {
	if {[catch { package require snack 2.0 }]} {
	    debugmsg tkabber \
		"unable to load the Snack package, so no sound support!\n\nThe Snack package is available at http://www.speech.kth.se/snack/index.html"
	    set options(sound) 0
	    return
	}

	foreach name $names {
	    if {$sounds($name) != ""} {
		snack::sound $sounds($name) -file $sounds($name)
	    }
	}
    }
}

proc sound::play {name {priority 0}} {
    global userstatus
    variable options
    variable play_id
    variable play_priority

    if {$name == ""} return
    if {$options(mute)} return

    if {$play_id != ""} {
	if {$priority >= $play_priority} {
	    return
	} else {
	    after cancel $play_id
	}
    }
    set play_id [after $options(delay) [list set [namespace current]::play_id {}]]
    set play_priority $priority

    if {$options(external_play_program) == ""} {
	$name play -block 0
    } else {
	catch { exec $options(external_play_program) $name & }
    }
}

proc sound::chat_message_notify_setup {jid type} {
    variable options
    variable groupchat_may_notify

    if {!$options(sound)} return

    if {$type == "groupchat"} {
	# Skip sound notifying on first messages until the first server message coming
	# Reasonable?
	set groupchat_may_notify($jid) 0
    }
}

proc sound::chat_message_notify {jid from type body extras} {
    variable options
    variable sounds
    variable groupchat_may_notify

    if {!$options(sound)} return

    if {[cequal $type groupchat] && [string equal $jid $from]} {
	set groupchat_may_notify($jid) 1
    }
    switch -- $type {
	groupchat {
	    if {$groupchat_may_notify($jid)} {
		if {[string equal $jid $from]} {
		    play $sounds(groupchat_server_message)
		} elseif {[chat::is_our_jid $jid $from]} {
		    play $sounds(groupchat_my_message)
		} else {
		    set myjid [chat::our_jid $jid]
		    set mynick [chat::get_nick $myjid $type]
		    if {[crange $body 0 [expr [clength $mynick] + 1]] == "${mynick}: "} {
			play $sounds(groupchat_their_message_to_me) -1
		    } else {
			play $sounds(groupchat_their_message)
		    }
		}
	    }
	}
	chat {
	    if {[chat::is_our_jid $jid $from]} {
		play $sounds(chat_my_message)
	    } else {
		play $sounds(chat_their_message) -1
	    }
	}
    }
}

proc sound::presence_notify {jid status} {
    variable options
    variable sounds

    if {!$options(sound)} return

    if {$status == "unavailable"} {
	play $sounds(presence_unavailable)
    } else {
	play $sounds(presence_available)
    }
}

proc sound::mute_setup {status} {
    variable options

    switch -- $status {
	xa -
	dnd {
	    set options(mute) 1
	}
	default {
	    set options(mute) 0
	}
    }
}

proc sound::connected_notify {} {
    variable options
    variable sounds

    if {!$options(sound)} return

    play $sounds(connected) 1
}

hook::add on_change_user_presence_hook [namespace current]::sound::presence_notify 100
hook::add change_our_presence_post_hook [namespace current]::sound::mute_setup 100
hook::add connected_hook [namespace current]::sound::connected_notify 100
hook::add postload_hook [namespace current]::sound::sound_setup 100
hook::add open_chat_post_hook [namespace current]::sound::chat_message_notify_setup 60
hook::add draw_message_hook [namespace current]::sound::chat_message_notify 19

